package Factory;
use strict;
use warnings;

use Config::Simple;
use WardenApp::Constants;
use WardenApp::DB;
use WardenApp::Utils;
use Data::Dumper;

use constant TRUE   => 1;
use constant FALSE  => 0;
use constant ENABLED  => 'yes';

use constant DB_ENGINE_MYSQL  => 'mysql';
use constant DB_ENGINE_SQLITE => 'sqlite';

use constant FACTORY_SECTION  => 'factory';
use constant CFG_MODULE_DIR   => 'GENERAL.modpath';


sub isModEnabled {
    my ($modprefix, $cfg) = @_;

    my $enabled = Constants::assignValue($modprefix . ".enabled", $cfg, FACTORY_SECTION);
    if ($enabled eq ENABLED) {
        return TRUE;
    }
    else {
        return FALSE;
    }
}

sub runModule {
    my ($modulename, $cfg, $dbh, $db_engine) = @_;
 
    unless(isModEnabled($modulename, $cfg)) {
        print "Module '$modulename' disabled! See configuration file!\n";
        return 0;    
    }
 
    my $moddir  = Constants::assignValue(CFG_MODULE_DIR,  $cfg, FACTORY_SECTION);
    my $module  = Constants::assignValue($modulename . ".module",  $cfg, FACTORY_SECTION, "nocheck");  
    
    require "$moddir/$module.pm";
    
    print "Module '$modulename' started\n"; 
    my $ret = $module->run($modulename, $cfg, $dbh, $db_engine); 
    
    if($ret) { 
        print "Module '$modulename' finished\n"; 
        return 1;
    }
    else {
        print "Module '$modulename' finished with errors\n"; 
        return 0;
    }
}
1;
