#!/usr/bin/perl
#
# getClients.pl
#
# Copyright (C) 2011-2015 Cesnet z.s.p.o
#
# Use of this source is governed by a BSD-style license, see LICENSE file.

use strict;
use warnings;

use Getopt::Std;
use DBI;
use DBD::mysql;
use FindBin qw($RealBin $RealScript);
FindBin::again();
use lib "$RealBin/../lib";
use WardenCommon;



################################################################################
#				VARIABLES
################################################################################
our $VERSION = "2.2";
my $etc = "$RealBin/../etc";

# read config file
my $conf_file = "$etc/warden-server.conf";
WardenCommon::loadConf($conf_file);



################################################################################
#				FUNCTIONS
################################################################################
sub usage {
  print "Usage: $RealScript (without parameters) [-h -V]\n";
  exit 1;
}


sub help {
  print "$RealScript (without parameters) [-h -V]\n";
  print "-h     print this text and exit\n";
  print "-V     print version and exit\n";
  exit 0;
}


sub version {
  print "Current version: $VERSION\n";
  exit 0;
}


################################################################################
#                               MAIN
################################################################################
our ($opt_h, $opt_V);

die usage unless getopts("hV");
my $help		= $opt_h;
my $script_version	= $opt_V;

# catch help option
if ($help) {
  help;
}

# catch version option
if ($script_version) {
  version;
}

# connect to DB
my $dbh = WardenCommon::connectDB($WardenCommon::DB_NAME, $WardenCommon::DB_HOST, $WardenCommon::DB_USER, $WardenCommon::DB_PASS);

# obtain data from DB
my $sth = $dbh->prepare("SELECT * FROM clients ORDER BY client_id ASC;") or die "Cannot prepare statement: " . $dbh->errstr;
$sth->execute or die "Cannot execute statement: " . $sth->errstr;
my $hash_ref = $sth->fetchall_hashref("client_id");

# print table of clients
print "+------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+\n";
print "| Client ID      | Hostname                             | Registered          | Requestor                   | Service                | CT | Type            | ROE | Description tags                              | IP Net Client      | V |\n";
print "+------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+\n";
foreach my $key (sort {$a<=>$b} keys %$hash_ref) {
  printf("| %-14s ", $hash_ref->{$key}->{client_id} || "unknown");
  printf("| %-36s ", $hash_ref->{$key}->{hostname} || "unknown");
  printf("| %19s ", $hash_ref->{$key}->{registered}  || "unknown");
  printf("| %-27s ", $hash_ref->{$key}->{requestor} || "unknown");
  printf("| %-22s ", $hash_ref->{$key}->{service} || "-");
  printf("| %-1s ", $hash_ref->{$key}->{client_type}  || "unknown");
  printf("| %-16s ", $hash_ref->{$key}->{type} || "-");
  printf("| %-1s ", $hash_ref->{$key}->{receive_own_events}  || "-");
  printf("| %-47s ", $hash_ref->{$key}->{description_tags} || "-");
  printf("| %-18s ", $hash_ref->{$key}->{ip_net_client}|| "unknown");
  printf("| %-1s |\n", $hash_ref->{$key}->{valid}|| "unknown");
}
print "+------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+\n";
print "\n";
print "Current registered clients at:\t" . scalar localtime(time) . " (generated in " .  scalar (time() - $^T) . " seconds)\n";

# cleanup section
END {
  if (defined $dbh) {
    $dbh->disconnect or warn "Disconnection from database '$WardenCommon::DB_NAME' failed: $dbh->errstr\n";
  }
}

exit 0;
