#!/usr/bin/perl
use strict;
use warnings;

use FindBin qw($Bin);
use lib "$Bin/../";

use WardenApp::DB;
use WardenApp::Constants;
use Config::Simple;

use constant GENERAL_CONFIG_FILE => "$Bin/../etc/cleaner.conf";
use constant DB_CONFIG_FILE => "$Bin/../etc/db.conf";
use constant RECV_CONFIG_FILE => "$Bin/../etc/receiver.conf";
use constant RECEIVER_SECTION => 'receiver';
use constant CLEANER_SECTION => 'cleaner';

use constant DB_ENGINE_MYSQL  => 'mysql';
use constant DB_ENGINE_SQLITE => 'sqlite';

use constant TRUE   => 1;
use constant FALSE  => 0;

my $cfg = new Config::Simple;
$cfg->read(GENERAL_CONFIG_FILE) or die $cfg->error();

my $cfg_rcv = new Config::Simple;
$cfg_rcv->read(RECV_CONFIG_FILE) or die $cfg_rcv->error();

my $cfg_db = new Config::Simple;
$cfg_db->read(DB_CONFIG_FILE) or die $cfg_db->error();

my @general_method          =  Constants::assignValue('GENERAL.method', $cfg, CLEANER_SECTION);
my $general_method_db       = (grep (/db/, @general_method) ? TRUE : FALSE);
my $general_maxage          =  Constants::assignValue('GENERAL.maxage', $cfg, CLEANER_SECTION);
$general_maxage             =  Constants::getDefaultValue('GENERAL.maxage', CLEANER_SECTION) if $general_maxage !~ /\d+[hdmHDM]/;

if($general_method_db) {
    my $db_engine =  Constants::assignValue('DB.dbengine', $cfg_rcv, RECEIVER_SECTION);
    my $dbh = DB::connectDB($cfg_db, $db_engine);
    if($dbh) {
        my $query = sprintf("DELETE FROM events WHERE %s", DB::getOldDataDB($db_engine, "OLDER", $general_maxage));
        my $sth = $$dbh->prepare($query);
        $sth->execute;

        my $num_deleted = $sth->rows;
        print "Removed '$num_deleted' events older than $general_maxage.\n";

        DB::closeDB($dbh);
        
        exit 1;
    }
    else {
        exit 0;    
    }
} 
else {
    print "General DB method is not configured\n";
    exit 0;
}

