#!/usr/bin/perl -w
use strict;
use warnings;

use FindBin qw($Bin);
use lib "$Bin/../";

use Config::Simple;
use WardenApp::DB;
use WardenApp::Receiver;
use WardenApp::Constants;

use constant GENERAL_CONFIG_FILE => "$Bin/../etc/receiver.conf";
use constant DB_CONFIG_FILE => "$Bin/../etc/db.conf";
use constant RECEIVER_SECTION => 'receiver';
use constant DEFAULT_REQ_ALL => "_all_";

use constant TRUE   => 1;
use constant FALSE  => 0;

use Data::Dumper;

my $cfg = new Config::Simple;
$cfg->read(GENERAL_CONFIG_FILE) or exit 0;

my $cfg_db = new Config::Simple;
$cfg_db->read(DB_CONFIG_FILE) or exit 0;

my @general_method          = Constants::assignValue('GENERAL.method',  $cfg, RECEIVER_SECTION);
my $general_method_stdout   = (grep (/stdout/, @general_method) ? TRUE : FALSE);
my $general_method_file     = (grep (/file/, @general_method) ? TRUE : FALSE);
my $general_method_db       = (grep (/db/, @general_method) ? TRUE : FALSE);

my $warden_path     = Constants::assignValue('GENERAL.wardenpath',      $cfg, RECEIVER_SECTION);
my $requested_type  = Constants::assignValue('GENERAL.requested_type',  $cfg, RECEIVER_SECTION);
$requested_type     = DEFAULT_REQ_ALL if $requested_type eq "";

my $logfile         = Constants::assignValue('GENERAL.logfile',         $cfg, RECEIVER_SECTION);
my $db_engine       = Constants::assignValue('DB.dbengine',               $cfg, RECEIVER_SECTION);

my $dbh             = DB::connectDB($cfg_db, $db_engine) if $general_method_db;
my $file_ref        = Receiver::openfile($cfg) if $general_method_file;  

require $warden_path . '/lib/WardenClientReceive.pm';

# Download of new evetns from Warden server
while (my @new_events = WardenClientReceive::getNewEvents($warden_path, $requested_type)) {
    foreach my $event_ref (@new_events) {
        if($general_method_stdout) {
            Receiver::printToStdout($event_ref); 
        }

        if($general_method_file) {
            Receiver::saveToFile($file_ref, $event_ref);
        }

        if($general_method_db) {
            Receiver::saveToDB($dbh, $event_ref, $db_engine);
        }
    }
}

DB::closeDB($dbh) if $general_method_db;
Receiver::closeFile($file_ref) if $general_method_file;

