#!/usr/bin/perl -w
#
# registerReceiver.pl
#
# Copyright (C) 2011-2012 Cesnet z.s.p.o
# Author(s): 	Tomas PLESNIK 	<plesnik@ics.muni.cz>
#               Jan SOUKAL      <soukal@ics.muni.cz>
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in
#    the documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the Cesnet z.s.p.o nor the names of its
#    contributors may be used to endorse or promote products derived from
#    this software without specific prior written permission.
#
# This software is provided ``as is'', and any express or implied
# warranties, including, but not limited to, the implied warranties of
# merchantability and fitness for a particular purpose are disclaimed.
# In no event shall the Cesnet z.s.p.o or contributors be liable for
# any direct, indirect, incidental, special, exemplary, or consequential
# damages (including, but not limited to, procurement of substitute
# goods or services; loss of use, data, or profits; or business
# interruption) however caused and on any theory of liability, whether
# in contract, strict liability, or tort (including negligence or
# otherwise) arising in any way out of the use of this software, even
# if advised of the possibility of such damage.

use strict;
use Getopt::Std;
use Switch;
use File::Basename;

our $VERSION = "0.1";

my $warden_path = '/opt/warden-server';
require $warden_path . '/lib/WardenReg.pm';
my $filename = basename($0);

#-------------------------------------------------------------------------------
#                               Functions
#-------------------------------------------------------------------------------
sub usage {
  print "Usage: $filename [-h -o -n <hostname> -r <requestor> -t <type> -i <ip_net_client>]\n";
  exit 1;
}


sub help {
  print "$filename [-h -o -n <hostname> -r <requestor> -t <type> -i <ip_net_client>]\n";
  print "-h     print this text and exit\n";
  print "-n     hostname of receiver\n";
  print "-r     client registration requestor\n";
  print "-t     type of received events\n";
  print "-o     enable receiving of own events\n";
  print "-i     CIDR of receiver\n";
  exit 0;
}


#-------------------------------------------------------------------------------
# errMsg - print error message and die
#-------------------------------------------------------------------------------
sub errMsg
{
  my $msg = shift;
  $msg = trim($msg);
  print $msg . "\n";
  exit 1;
} # End of errMsg


#-------------------------------------------------------------------------------
# trim - remove whitespace from the start and end of the string
#-------------------------------------------------------------------------------
sub trim
{
  my $string = shift;
  $string =~ s/^\s+//;
  $string =~ s/\s+$//;
  return $string;
} # End of trim


#-------------------------------------------------------------------------------
#                               MAIN
#-------------------------------------------------------------------------------
our ($opt_n, $opt_r, $opt_t, $opt_o, $opt_i, $opt_h);

if ($#ARGV == -1) {usage}

die usage unless getopts("n:r:t:i:ho");
my $hostname            = $opt_n;
my $requestor           = $opt_r;
my $type		= $opt_t;
my $ip_net_client       = $opt_i;
my $help                = $opt_h;
my $receive_own_events	= "f";

if ($opt_o) {
  $receive_own_events = "t";
}

# catch help param
if ($help) {
  help;
}

# superuser controle
my $UID = $<;
if ($UID != 0) {die errMsg("You must be root for running this script!")}

# check parameters definition
switch () {
  case {!defined $hostname} { print "ERROR: Parameter 'hostname' is not defined!\n"; exit 1; }
  case {!defined $requestor} { print "ERROR: Parameter 'requestor' is not defined!\n"; exit 1; }
  case {!defined $type} { print "ERROR: Parameter 'type' is not defined!\n"; exit 1; }
  case {!defined $receive_own_events} { print "ERROR: Parameter 'receive_own_events' is not defined!\n"; exit 1; }
  case {!defined $ip_net_client} { print "ERROR: Parameter 'ip_net_client' is not defined!\n"; exit 1; }
}

my $return = WardenReg::registerReceiver($warden_path, $hostname, $requestor, $type, $receive_own_events, $ip_net_client);
$return ? print "Registration of $hostname was SUCCESSFUL...\n" : print "Registration of $hostname FAILED!\n";

exit 0;
