#!/usr/bin/perl -w
#
# unregisterClient.pl
#
# Copyright (C) 2011-2012 Cesnet z.s.p.o
#
# Use of this source is governed by a BSD-style license, see LICENSE file.

use strict;
use Getopt::Std;
use Switch;
use File::Basename;

our $VERSION = "2.0";

my $warden_path = '/opt/warden-server';
require $warden_path . '/lib/WardenReg.pm';
my $filename = basename($0);

#-------------------------------------------------------------------------------
#                               Functions
#-------------------------------------------------------------------------------
sub usage {
  print "Usage: $filename [-h -i <client_id>]\n";
  exit 1;
}

sub help {
  print "$filename [-h -i <client_id>]\n";
  print "-h     print this text and exit\n";
  print "-i     client_id for unregistration\n";
  exit 0;
}


#-------------------------------------------------------------------------------
# errMsg - print error message and die
#-------------------------------------------------------------------------------
sub errMsg
{
  my $msg = shift;
  $msg = trim($msg);
  print $msg . "\n";
  exit 1;
} # End of errMsg


#-------------------------------------------------------------------------------
# trim - remove whitespace from the start and end of the string
#-------------------------------------------------------------------------------
sub trim
{
  my $string = shift;
  $string =~ s/^\s+//;
  $string =~ s/\s+$//;
  return $string;
} # End of trim


#-------------------------------------------------------------------------------
#                               MAIN
#-------------------------------------------------------------------------------
our ($opt_h, $opt_i);

if ($#ARGV == -1) {usage}

die usage unless getopts("i:h");
my $client_id	= $opt_i;
my $help        = $opt_h;

# catch help param
if ($help) {
	  help;
}

# superuser controle
my $UID = $<;
if ($UID != 0) {die errMsg("You must be root for running this script!")}

# check parameters definition
if (!defined $client_id) {
  print "ERROR: Parameter 'client_id' is not defined!\n";
  exit 1;
}

my $return = WardenReg::unregisterClient($warden_path, $client_id);
$return ? print "Unregistration of client (#$client_id) was SUCCESSFUL...\n" : print "Unregistration of client (# $client_id) FAILED!\n";

exit 0;
